@@ -176,10 +176,10 @@ kable(InflObs)
 ```   \n\n'), file=RmdName, append=TRUE)
 
 # stop writing markdown and process the written file into html and an R script
-knit2html(RmdName, quiet=TRUE)
+knit2html(RmdName, quiet=TRUE, stylesheet=system.file("css", "BrailleR.css", package="BrailleR"))
 file.remove(sub(".Rmd", ".md", RmdName))
 purl(RmdName, quiet=TRUE)
-if(interactive()) browseURL(sub(".Rmd", ".html", RmdName))
+if(getOption("BrailleR.View")) browseURL(sub(".Rmd", ".html", RmdName))
 
 # do the clean up
 #rm(list=c("Residuals", "Fits", "Leverages", "Cooks"), envir=.GlobalEnv)
